@@ -40,7 +40,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : callback_object(0), handle(0) {}
+            Resource() : callback_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_callback *callback_object;
@@ -66,8 +66,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -86,6 +86,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -94,6 +95,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_callback *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_compositor
@@ -109,7 +114,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : compositor_object(0), handle(0) {}
+            Resource() : compositor_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_compositor *compositor_object;
@@ -135,8 +140,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -155,6 +160,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -174,6 +180,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_compositor *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_shm_pool
@@ -189,7 +199,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : shm_pool_object(0), handle(0) {}
+            Resource() : shm_pool_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_shm_pool *shm_pool_object;
@@ -215,8 +225,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -236,6 +246,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -263,6 +274,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_shm_pool *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_shm
@@ -278,7 +293,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : shm_object(0), handle(0) {}
+            Resource() : shm_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_shm *shm_object;
@@ -304,8 +319,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -393,6 +408,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -410,6 +426,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_shm *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_buffer
@@ -425,7 +445,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : buffer_object(0), handle(0) {}
+            Resource() : buffer_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_buffer *buffer_object;
@@ -451,8 +471,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -473,6 +493,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -487,6 +508,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_buffer *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_data_offer
@@ -502,7 +527,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : data_offer_object(0), handle(0) {}
+            Resource() : data_offer_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_data_offer *data_offer_object;
@@ -528,8 +553,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -552,6 +577,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -576,6 +602,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_data_offer *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_data_source
@@ -591,7 +621,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : data_source_object(0), handle(0) {}
+            Resource() : data_source_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_data_source *data_source_object;
@@ -617,8 +647,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -644,6 +674,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -662,6 +693,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_data_source *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_data_device
@@ -677,7 +712,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : data_device_object(0), handle(0) {}
+            Resource() : data_device_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_data_device *data_device_object;
@@ -703,8 +738,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -736,6 +771,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -759,6 +795,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_data_device *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_data_device_manager
@@ -774,7 +814,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : data_device_manager_object(0), handle(0) {}
+            Resource() : data_device_manager_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_data_device_manager *data_device_manager_object;
@@ -800,8 +840,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -820,6 +860,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -840,6 +881,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_data_device_manager *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_shell
@@ -855,7 +900,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : shell_object(0), handle(0) {}
+            Resource() : shell_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_shell *shell_object;
@@ -881,8 +926,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -900,6 +945,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -916,6 +962,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_shell *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_shell_surface
@@ -931,7 +981,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : shell_surface_object(0), handle(0) {}
+            Resource() : shell_surface_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_shell_surface *shell_surface_object;
@@ -957,8 +1007,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1015,6 +1065,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1078,6 +1129,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_shell_surface *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_surface
@@ -1093,7 +1148,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : surface_object(0), handle(0) {}
+            Resource() : surface_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_surface *surface_object;
@@ -1119,8 +1174,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1156,6 +1211,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1206,6 +1262,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_surface *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_seat
@@ -1221,7 +1281,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : seat_object(0), handle(0) {}
+            Resource() : seat_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_seat *seat_object;
@@ -1247,8 +1307,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1279,6 +1339,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1302,6 +1363,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_seat *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_pointer
@@ -1317,7 +1382,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : pointer_object(0), handle(0) {}
+            Resource() : pointer_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_pointer *pointer_object;
@@ -1343,8 +1408,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1384,6 +1449,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1405,6 +1471,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_pointer *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_keyboard
@@ -1420,7 +1490,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : keyboard_object(0), handle(0) {}
+            Resource() : keyboard_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_keyboard *keyboard_object;
@@ -1446,8 +1516,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1488,6 +1558,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1502,6 +1573,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_keyboard *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_touch
@@ -1517,7 +1592,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : touch_object(0), handle(0) {}
+            Resource() : touch_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_touch *touch_object;
@@ -1543,8 +1618,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1573,6 +1648,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1587,6 +1663,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_touch *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_output
@@ -1602,7 +1682,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : output_object(0), handle(0) {}
+            Resource() : output_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_output *output_object;
@@ -1628,8 +1708,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1679,6 +1759,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1687,6 +1768,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_output *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_region
@@ -1702,7 +1787,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : region_object(0), handle(0) {}
+            Resource() : region_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_region *region_object;
@@ -1728,8 +1813,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1749,6 +1834,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1777,6 +1863,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_region *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_subcompositor
@@ -1792,7 +1882,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : subcompositor_object(0), handle(0) {}
+            Resource() : subcompositor_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_subcompositor *subcompositor_object;
@@ -1818,8 +1908,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1842,6 +1932,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1862,6 +1953,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_subcompositor *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 
     class Q_WAYLAND_SERVER_WAYLAND_EXPORT wl_subsurface
@@ -1877,7 +1972,7 @@ namespace QtWaylandServer {
         class Resource
         {
         public:
-            Resource() : subsurface_object(0), handle(0) {}
+            Resource() : subsurface_object(nullptr), handle(nullptr) {}
             virtual ~Resource() {}
 
             wl_subsurface *subsurface_object;
@@ -1903,8 +1998,8 @@ namespace QtWaylandServer {
         QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
         const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }
 
-        bool isGlobal() const { return m_global != 0; }
-        bool isResource() const { return m_resource != 0; }
+        bool isGlobal() const { return m_global != nullptr; }
+        bool isResource() const { return m_resource != nullptr; }
 
         static const struct ::wl_interface *interface();
         static QByteArray interfaceName() { return interface()->name; }
@@ -1931,6 +2026,7 @@ namespace QtWaylandServer {
     private:
         static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
         static void destroy_func(struct ::wl_resource *client_resource);
+        static void display_destroy_func(struct ::wl_listener *listener, void *data);
 
         Resource *bind(struct ::wl_client *client, uint32_t id, int version);
         Resource *bind(struct ::wl_resource *handle);
@@ -1964,6 +2060,10 @@ namespace QtWaylandServer {
         Resource *m_resource;
         struct ::wl_global *m_global;
         uint32_t m_globalVersion;
+        struct DisplayDestroyedListener : ::wl_listener {
+            wl_subsurface *parent;
+        };
+        DisplayDestroyedListener m_displayDestroyedListener;
     };
 }
 
